@@ -4,6 +4,7 @@ from spacy.language import Language, component
 from spacy.tokens import Doc, Span, Token
 
 __all__ = [
+    "bunsetu_available",
     "bunsetu_span",
     "bunsetu_spans",
     "bunsetu_phrase_span",
@@ -40,6 +41,10 @@ POS_PHRASE_MAP = {
 }
 
 
+def bunsetu_available(span: Span):
+    return "bunsetu_heads" in span.doc.user_data
+
+
 def bunsetu_head_list(span: Span) -> Iterable[int]:
     doc = span.doc
     heads = doc.user_data["bunsetu_heads"]
